Learn R Programming

dualtrees (version 0.1.5)

cen2uv: centre to vector

Description

transforms the angle and radius component of the spectral centre into vector components for visualization

Usage

cen2uv(cen)

Value

an nx x ny x 2 array, the two matrices representing the u- and v-component of the vector field.

Arguments

cen

an nx x ny x 3 array, the output of dt2cen

Details

The resulting vector field represents the degree of anisotropy and the dominant direction, averaged over all scales.

See Also

dt2cen, uvplot

Examples

Run this code
dt <- fld2dt(blossom)
ce <- dt2cen(dt)
uv <- cen2uv(ce)
uvplot( uv, z=blossom )

Run the code above in your browser using DataLab