powered by
transforms the angle and radius component of the spectral centre into vector components for visualization
cen2uv(cen)
an nx x ny x 2 array, the two matrices representing the u- and v-component of the vector field.
nx x ny x 2
an nx x ny x 3 array, the output of dt2cen
nx x ny x 3
dt2cen
The resulting vector field represents the degree of anisotropy and the dominant direction, averaged over all scales.
dt2cen, uvplot
uvplot
dt <- fld2dt(blossom) ce <- dt2cen(dt) uv <- cen2uv(ce) uvplot( uv, z=blossom )
Run the code above in your browser using DataLab